@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Clustering/ClusteringStrategy.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -138,7 +138,7 @@ void ClusteringStrategy::setInitParam(std::string & paramFileName, int64_t posit
 }
 
 void ClusteringStrategy::setTabInitParameter(
-		Parameter ** tabInitParameter, int64_t nbInitParameter) 
+		Parameter ** tabInitParameter, int64_t nbInitParameter)
 {
 	_strategyInit->setTabInitParameter(tabInitParameter, nbInitParameter);
 }
@@ -178,8 +178,9 @@ void ClusteringStrategy::insertAlgo(AlgoName algoName, int64_t position) {
 // removeAlgo
 void ClusteringStrategy::removeAlgo( unsigned int position) {
 	if ( position < _tabAlgo.size() ) {
-		_tabAlgo.erase(_tabAlgo.begin() + position);
-		_nbAlgo--;
+      if(_tabAlgo[position]) delete _tabAlgo[position];
+      _tabAlgo.erase(_tabAlgo.begin() + position);
+      _nbAlgo--;
 	}
 }
 
@@ -190,13 +191,13 @@ void ClusteringStrategy::setStrategyInit(ClusteringStrategyInit * iStrategyInit)
 	_strategyInit = iStrategyInit; //copy constructor
 }
 
-void ClusteringStrategy::setStrategyInit(StrategyInitName initName, Data *& data, 
-		int64_t nbNbCluster, int64_t * tabNbCluster, ModelType * modelType) 
+void ClusteringStrategy::setStrategyInit(StrategyInitName initName, Data *& data,
+		int64_t nbNbCluster, int64_t * tabNbCluster, ModelType * modelType)
 {
 	int64_t nbSample    = data->_nbSample;
 	int64_t pbDimension  = data->_pbDimension;
 
-	// TODO [bauder]: Why do we initialize with an empty filename ? 
+	// TODO [bauder]: Why do we initialize with an empty filename ?
 	//                Maybe add a function parameter ?
 	std::string fileName = "";
 
@@ -275,12 +276,13 @@ void ClusteringStrategy::setNbTry(int64_t nbTry) {
 void ClusteringStrategy::run(Model *& model) const {
 	//cout<<"XEMClusteringStrategy Init, nbTry="<<_nbTry<<endl;
 	if (_nbTry == 1) {
-		oneTry(model);
+      oneTry(model, true);
 	}
 	else {
 		Model * bestModel = model->clone();
-		oneTry(bestModel);
-		// first tries
+	  oneTry(bestModel);
+
+		// first tries : try until one model has "noerror"
 		int iTry = 1;
 		while ( !((bestModel->getErrorType()) == NOERROR) && ( iTry < _nbTry ) ) {
 			delete bestModel;
@@ -306,6 +308,9 @@ void ClusteringStrategy::run(Model *& model) const {
 				delete currentModel;
 			}
 		}
+		else{//there is no try with NOERROR
+      THROW(OtherException, AllTriesGotErros);
+		}
 		delete model;
 		model = bestModel;
 		/*    oneTry(model);
@@ -315,8 +320,8 @@ void ClusteringStrategy::run(Model *& model) const {
 			for (int64_t i=1; i<_nbTry; i++){
 			  oneTry(model);
 			  double lastLLorCLL = model->getCompletedLogLikelihoodOrLogLikelihood();
-			  cout<<"Try n°="<< i << " lastLL=" << lastLLorCLL << " bestLL=" << bestLLorCLL 
-		      << " nbCluster=" << model->getNbCluster() << " modelName=" 
+			  cout<<"Try n°="<< i << " lastLL=" << lastLLorCLL << " bestLL=" << bestLLorCLL
+		      << " nbCluster=" << model->getNbCluster() << " modelName="
 		      << XEMModelNameToString(model->getModelType()->getModelName()) << endl;
 			  if (lastLLorCLL > bestLLorCLL){
 				delete bestModel;
@@ -333,9 +338,10 @@ void ClusteringStrategy::run(Model *& model) const {
 //------
 //oneTry
 //------
-void ClusteringStrategy::oneTry(Model *& model) const {
-
-	//init model
+  void ClusteringStrategy::oneTry(Model *& model, bool doThrow) const {
+  try{
+	//1 init model
+	//------------
 	switch (_strategyInit->getStrategyInitName()) {
 
 	case RANDOM:
@@ -350,7 +356,7 @@ void ClusteringStrategy::oneTry(Model *& model) const {
 		bool ok = false;
 		int64_t nbInitParameter = _strategyInit->getNbInitParameter();
 		while (ok == false && index < nbInitParameter) {
-			int64_t nbClusterOfInitParameter = 
+			int64_t nbClusterOfInitParameter =
 					_strategyInit->getInitParameter(index)->getNbCluster();
 			if (nbCluster == nbClusterOfInitParameter) {
 				ok = true;
@@ -406,6 +412,9 @@ void ClusteringStrategy::oneTry(Model *& model) const {
 		THROW(InputException, wrongStrategyInitName);
 	}
 
+
+	// 2. Algo(s)
+	//-----------
 	model->setAlgoName(UNKNOWN_ALGO_NAME);
 
 	// model->getParameter()->edit();
@@ -424,18 +433,27 @@ void ClusteringStrategy::oneTry(Model *& model) const {
 			_tabAlgo[i]->run(model);
 		}
 		catch (Exception&errorType) {
-			
-			if (VERBOSE)
+
+			if (VERBOSE == 1)
 				errorType.run();
-			
+
 			++nbErrorInAlgo;
 			// set error for that model
 			if ( nbErrorInAlgo == _nbAlgo ) {
 				model->setError(errorType);
-				throw;
+				throw; //TODO FL
 			}
 		}
 	}
+  }//fin try
+  //s'il y a eu un throw, normalement le model n'est pas noerror
+  // il ne faut pas que le throw aille plus haut car il y a éventuellement plusieurs nbTry
+  catch(Exception & error){
+    //cout<<"erreur dans un oneRun, on continue"<<endl;
+      //Nothing to do
+    // except when nbTry==1
+    if(doThrow) THROW(OtherException, AllTriesGotErros); 
+  }
 }
 
 //-------
@@ -445,7 +463,7 @@ bool ClusteringStrategy::verify() {
 
 	bool res = true;
 
-	// Test 
+	// Test
 	//-----
 	// nbAlogType > 0
 	if (_nbAlgo < 1 || _tabAlgo.empty()) {
@@ -472,8 +490,8 @@ bool ClusteringStrategy::verify() {
 // Input strategy
 // TODO XEMInput : a enlever
 //---------------
-void ClusteringStrategy::input_FLAT_FORMAT(std::ifstream & fi, Data *& data, 
-		int64_t nbNbCluster, int64_t * tabNbCluster, ModelType * modelType) 
+void ClusteringStrategy::input_FLAT_FORMAT(std::ifstream & fi, Data *& data,
+		int64_t nbNbCluster, int64_t * tabNbCluster, ModelType * modelType)
 {
 	int64_t j;
 	std::string keyWord = "";
