@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/DiscriminantAnalysis/Predict/PredictMain.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -62,7 +62,12 @@ PredictMain::~PredictMain() {
 //---
 //run
 //---
-void PredictMain::run() {
+void PredictMain::run(IoMode iomode, int verbose, int massiccc) {
+
+//TODO: naming conventions ? (this doesn't look good)
+	IOMODE = iomode;
+	VERBOSE = verbose;
+  MASSICCC = massiccc;
 
 	if (!_input) {
 		THROW(OtherException, nullPointerError);
@@ -136,7 +141,7 @@ void PredictMain::run() {
 	}
 	catch (Exception&errorType) {
 		
-		if (VERBOSE) {
+		if (VERBOSE == 1) {
 			Error error(errorType);
 			error.run();
 		}
