@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/Algo/Algo.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -84,6 +84,7 @@ bool Algo::continueAgain() {
 	//cout<<"Algo::continueAgain"<<endl;
 	bool result, res1, res2;
 	double diff;
+	ofstream progressFile;
 
 	if (_indexIteration == 1) {
 		result = true;
@@ -97,31 +98,60 @@ bool Algo::continueAgain() {
 		}
 		else {
 			switch (_algoStopName) {
-			case NBITERATION:
-				result = (_indexIteration <= _nbIteration);
-				break;
+				case NBITERATION:
+					if (MASSICCC == 10) {
+						progressFile.open ("progress.json");
+						progressFile << "{ \"Progress\" : " << ((double)_indexIteration - 1.0)/(double)_nbIteration * 100.0 << "}";
+						progressFile.close();
+					}
+					result = (_indexIteration <= _nbIteration);
+					break;
 
-			case EPSILON:
-				if (_indexIteration <= 3) {
-					result = true;
-				}
-				else {
-					diff = fabs(_xml - _xml_old);
-					result = (diff >= _epsilon);
-				}
-				break;
+				case EPSILON:
+					if (MASSICCC == 10) {
+						progressFile.open ("progress.json");
+						progressFile << "{ \"Progress\" : " << ((double)_indexIteration - 1.0)/1000.0 * 100.0 << "}";
+						progressFile.close();
+					}
+					if (_indexIteration <= 3) {
+						result = true;
+					}
+					else {
+						diff = fabs(_xml - _xml_old);
+						result = (diff >= _epsilon);
+					}
+					if (!result) {
+						if (MASSICCC == 10) {
+							progressFile.open ("progress.json");
+							progressFile << "{ \"Progress\" : 100 }";
+							progressFile.close();
+						}
+						break;
+					}
 
-			case NBITERATION_EPSILON:
-				res1 = (_indexIteration <= _nbIteration);
-				if (_indexIteration <= 3) {
-					res2 = true;
-				}
-				else {
-					diff = fabs(_xml - _xml_old);
-					res2 = (diff >= _epsilon);
-				};
-				result = (res1 && res2);
-				break;
+				case NBITERATION_EPSILON:
+					if (MASSICCC == 10) {
+						progressFile.open ("progress.json");
+						progressFile << "{ \"Progress\" : " << ((double)_indexIteration - 1.0)/(double)_nbIteration * 100.0 << "}";
+						progressFile.close();
+					}
+					res1 = (_indexIteration <= _nbIteration);
+					if (_indexIteration <= 3) {
+						res2 = true;
+					}
+					else {
+						diff = fabs(_xml - _xml_old);
+						res2 = (diff >= _epsilon);
+					};
+					result = (res1 && res2);
+					if (!result) {
+						if (MASSICCC == 10) {
+							progressFile.open ("progress.json");
+							progressFile << "{ \"Progress\" : 100 }";
+							progressFile.close();
+						}
+						break;
+					}
 
 			default: result = (_indexIteration <= _nbIteration);
 			}
