@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/IO/Input.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -62,8 +62,8 @@ Input::Input(const Input & input) {
 		_knownPartition = new Partition(input._knownPartition);
 	}
 
-	if (!_knownLabelDescription)
-		delete _knownLabelDescription;
+//if (!_knownLabelDescription) ??
+//  delete _knownLabelDescription;
 
 	_knownLabelDescription = NULL;
 	if (input._knownLabelDescription != NULL) {
@@ -188,7 +188,8 @@ void Input::setModel(std::vector<ModelName> const & modelName) {
 	_modelType.resize(modelName.size());
 	for (unsigned int iModel = 0; iModel < _modelType.size(); iModel++) {
 		// copy vector contents
-		_modelType[iModel] = new ModelType(modelName[iModel]);
+      if(_modelType[iModel]) delete _modelType[iModel];
+      _modelType[iModel] = new ModelType(modelName[iModel]);
 	}
 }
 
@@ -323,7 +324,7 @@ void Input::setKnownPartition(std::string iFileName) {
 
 // insertKnownPartition
 //---------------------
-void Input::insertKnownPartition(std::string iFileName) {
+void Input::insertKnownPartition(NumericPartitionFile partitionFile) {
 	if (_nbCluster.size() != 1) {
 		THROW(InputException, badSetKnownPartition);
 	}
@@ -331,10 +332,6 @@ void Input::insertKnownPartition(std::string iFileName) {
 		if (_knownPartition) {
 			delete _knownPartition;
 		}
-		NumericPartitionFile partitionFile;
-		partitionFile._fileName = iFileName;
-		partitionFile._format = FormatNumeric::defaultFormatNumericFile;
-		partitionFile._type = TypePartition::defaultTypePartition;
 		_knownPartition = new Partition(_nbSample, _nbCluster[0], partitionFile);
 	}
 	_finalized = false;
