@@ -1,12 +1,12 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/IO/Label.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
 /***************************************************************************
     This file is part of MIXMOD
-
+    
     MIXMOD is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
@@ -20,7 +20,7 @@
     You should have received a copy of the GNU General Public License
     along with MIXMOD.  If not, see <http://www.gnu.org/licenses/>.
 
-    All informations available on : http://www.mixmod.org
+    All informations available on : http://www.mixmod.org                                                                                               
 ***************************************************************************/
 #include "mixmod/Kernel/IO/Label.h"
 #include "mixmod/Kernel/IO/LabelDescription.h"
@@ -58,24 +58,26 @@ Label::Label(Model * model) {
 
 	// compute tabLabel
 	//-----------------
-	int64_t * tabLabel = NULL;
+	//int64_t * tabLabel_p = NULL;
+    std::unique_ptr<int64_t[]>  tabLabel;
 	int64_t nbCluster = model->getNbCluster();
-
 	ModelType * modelType = model->getModelType();
 	bool binary = isBinary(modelType->_nameModel);
 
 	if (!binary || (binary && !DATA_REDUCE)) {
 		_nbSample = model->getNbSample();
-		int64_t ** tabPartition = new int64_t*[_nbSample];
+		//int64_t ** tabPartition = new int64_t*[_nbSample];
+        std::unique_ptr<int64_t*[], TabDeleter<int64_t>>  tabPartition(new int64_t*[_nbSample], TabDeleter<int64_t>(_nbSample));
 		for (int64_t i = 0; i < _nbSample; i++) {
 			tabPartition[i] = new int64_t[nbCluster];
 		}
-		tabLabel = new int64_t[_nbSample];
-		model->getLabelAndPartitionByMAPOrKnownPartition(tabLabel, tabPartition);
-		for (int64_t i = 0; i < _nbSample; i++) {
-			delete [] tabPartition[i];
-		}
-		delete [] tabPartition;
+		//tabLabel = new int64_t[_nbSample];
+        tabLabel.reset(new int64_t[_nbSample]); //provides exception-safe deletion
+		model->getLabelAndPartitionByMAPOrKnownPartition(tabLabel.get(), tabPartition.get());
+		//for (int64_t i = 0; i < _nbSample; i++) {
+		//	delete [] tabPartition[i];
+		//}
+		//delete [] tabPartition;
 	}
 
 	else {
@@ -83,16 +85,18 @@ Label::Label(Model * model) {
 		const vector<int64_t> & correspondenceOriginDataToReduceData =
 				dynamic_cast<BinaryModel*> (model)->getCorrespondenceOriginDataToReduceData();
 		_nbSample = correspondenceOriginDataToReduceData.size();
-		tabLabel = new int64_t[_nbSample];
-
+		//tabLabel = new int64_t[_nbSample];
+        tabLabel.reset(new int64_t[_nbSample]); //provides exception-safe deletion
 		//label et partition on reduceData
 		int64_t nbSampleOfDataReduce = model->getNbSample();
-		int64_t * tabLabelReduce = new int64_t[nbSampleOfDataReduce];
-		int64_t ** tabPartitionReduce = new int64_t*[nbSampleOfDataReduce];
+		//int64_t * tabLabelReduce = new int64_t[nbSampleOfDataReduce];
+		std::unique_ptr<int64_t[]> tabLabelReduce(new int64_t[nbSampleOfDataReduce]);        
+		//int64_t ** tabPartitionReduce = new int64_t*[nbSampleOfDataReduce];
+        std::unique_ptr<int64_t*[], TabDeleter<int64_t>>  tabPartitionReduce(new int64_t*[nbSampleOfDataReduce], TabDeleter<int64_t>(nbSampleOfDataReduce));
 		for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
 			tabPartitionReduce[i] = new int64_t[nbCluster];
 		}
-		model->getLabelAndPartitionByMAPOrKnownPartition(tabLabelReduce, tabPartitionReduce);
+		model->getLabelAndPartitionByMAPOrKnownPartition(tabLabelReduce.get(), tabPartitionReduce.get());
 
 		//  double ** tabPostProbaReduce = NULL;
 		//  tabPostProbaReduce = copyTab(estimation->getModel()->getPostProba(),
@@ -103,17 +107,17 @@ Label::Label(Model * model) {
 			tabLabel[i] = tabLabelReduce[correspondenceOriginDataToReduceData[i]];
 		}
 
-		//delete
-		for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
-			delete [] tabPartitionReduce[i];
-		}
-		delete [] tabPartitionReduce;
-		delete[] tabLabelReduce;
+		//delete //deletion is made by unique_ptr
+		//for (int64_t i = 0; i < nbSampleOfDataReduce; i++) {
+		//	delete [] tabPartitionReduce[i];
+		//}
+		//delete [] tabPartitionReduce;
+		//delete[] tabLabelReduce;
 	}
 
 	// compute _label
-	recopyTabToVector(tabLabel, _label, _nbSample);
-	delete [] tabLabel;
+	recopyTabToVector(tabLabel.get(), _label, _nbSample);
+	//delete [] tabLabel; //deletion done by unique_ptr
 }
 
 //------------
@@ -196,7 +200,9 @@ int64_t** Label::getClassificationTab(std::vector<int64_t> const & label, int64_
 	// loop over labels
 	for (int64_t i = 0; i < _nbSample; i++) {
 	  //cout<<_label[i]<<endl;
+      if(label[i] > 0){
 		++classTab[_label[i] - 1][label[i] - 1];
+      }
 	}
 
 	return classTab;
