@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Kernel/IO/ParameterDescription.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -177,12 +177,12 @@ ParameterDescription::ParameterDescription(
 	recopyVectorToTab(nbFactor, tabNbFactor);
 
 	GaussianGeneralParameter* gaussian_parameter =
-		new GaussianGeneralParameter(nbCluster, nbVariable_gaussian, _modelType, filename);
+		new GaussianGeneralParameter(nbCluster, nbVariable_gaussian, _modelType, filename, nbVariable_binary, nbFactor);
 	BinaryEkjhParameter* binary_parameter =
 		new BinaryEkjhParameter(
 			nbCluster, nbVariable_binary, _modelType, tabNbFactor, filename);
 
-	_parameter = new CompositeParameter(binary_parameter, gaussian_parameter, _modelType);
+	_parameter = new CompositeParameter(gaussian_parameter, binary_parameter, _modelType);
 }
 
 //constructor using XEMParameter
