@@ -1,6 +1,6 @@
 /***************************************************************************
                              SRC/mixmod/Matrix/SymmetricMatrix.cpp  description
-    copyright            : (C) MIXMOD Team - 2001-2014
+    copyright            : (C) MIXMOD Team - 2001-2016
     email                : contact@mixmod.org
  ***************************************************************************/
 
@@ -559,12 +559,13 @@ void SymmetricMatrix::input(std::ifstream & fi) {
 	double garbage;
 
 	for (i = 0; i < _s_pbDimension; i++) {
-		for (j = 0; j < i + 1; j++) {
-			fi >> _store[r];
-			r++;
-		}
-		for (j = i + 1; j < _s_pbDimension; j++) {
-			fi >> garbage;
+    for (j = 0; j < i + 1; j++) {
+			_store[r] = getDoubleFromStream(fi);
+      r++;
+    }
+    for (j = i + 1; j < _s_pbDimension; j++) {
+			// we don't need values (all are 0 ?)
+			getDoubleFromStream(fi);
 		}
 	}
 }
